@@ -8,20 +8,20 @@
  *
  * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
+ * This program is free software; you can redistribute it and/or 
+ * modify it under the terms of the GNU General Public License as 
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the 
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA  02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
+ * USA
  */
 
 #ifndef GCU_ELEMENT_H
@@ -36,14 +36,14 @@
 
 using namespace std;
 
-class EltTable;
-
 /*!\namespace gcu
 The namespace used for all C++ classes provided by the Gnome Chemistry Utils.
 */
 namespace gcu
 {
 
+class EltTable;
+
 /*!\class Element gcu/element.h
 	Represents a chemical element.
 	This class has no public constructor or destructor. The instances are created by the framework
@@ -225,7 +225,11 @@ public:
 	element.
 	*/
 	IsotopicPattern *GetIsotopicPattern (unsigned natoms);
-	
+	string const& GetElectronicConfiguration () {return ElecConfig;}
+	map<string, string> const& GetNames () {return names;}
+	GcuDimensionalValue const *GetIonizationEnergy (int rank = 1);
+	GcuDimensionalValue const *GetElectronAffinity (int rank = 1);
+
 private:
 	unsigned char m_Z, m_nve, m_tve, m_maxve;
 	char m_Symbol[4];
@@ -241,6 +245,7 @@ private:
 	vector<Isotope*> m_isotopes;
 	vector<IsotopicPattern*> m_patterns;
 	map<string, string> names;
+	string ElecConfig;
 };
 
 } // namespace gcu
